## steps is a vector 
simulate_pars_gaussian <- function(par.prior.dist, par.param, steps, nsims, shift_only){
    
    tmp_mean <- par.prior.dist[["mean"]]
    tmp_sd <- par.prior.dist[["sd"]]
    nsteps <- length(steps)

    if(length(par.param) == 1 || length(unique(par.param)) == 1){
        if(shift_only){
            ret <- matrix(NA, nsims, nsteps)
            ret[, 1] <- stats::rnorm(nsims, tmp_mean, tmp_sd)
            ret[, -1] <- ret[, 1]
        }else{
            ret <- matrix(stats::rnorm(nsims*nsteps, tmp_mean, tmp_sd), nsims, nsteps)
        }
    }else{
        ret <- matrix(NA, nsims, nsteps)
        if(shift_only){
            ret <- matrix(NA, nsims, nsteps)
            ret[, 1] <- stats::rnorm(nsims, tmp_mean, tmp_sd)
            del <- ret[, 1] - par.param[steps[1]]
            if(nsteps > 1){
                for(t in 2:nsteps){
                    ret[, t] <- del + par.param[steps[t]]
                }
            }
        }else{
            tmp_mean <- tmp_mean[steps]
            tmp_sd <- tmp_sd[steps]
            for(i in 1:nsteps){
                ret[, i] <- stats::rnorm(nsims, tmp_mean[i], tmp_sd[i])
            }
        }
    }
    
    ret[ret < 0] <- 0.001
    
    return(ret)
}

simulate_pars_beta <- function(par.prior.dist, par.param, steps, nsims, shift_only){
    
    tmp_a <- par.prior.dist[["a"]]
    tmp_b <- par.prior.dist[["b"]]
    nsteps <- length(steps)
    
    if(length(par.param) == 1){
        if(shift_only){
            ret <- matrix(NA, nsims, nsteps)
            ret[, 1] <- stats::rbeta(nsims, tmp_a, tmp_b)
            ret[, -1] <- ret[, 1]
        }else{
            ret <- matrix(stats::rbeta(nsims*nsteps, tmp_a, tmp_b), nsims, nsteps)   
        }
    }else{
        ret <- matrix(NA, nsims, nsteps)
        if(shift_only){
            ret[, 1] <- stats::rbeta(nsims, tmp_a, tmp_b)
            del <- ret[, 1] - par.param[steps[1]]
            if(nsteps > 1){
                for(t in 2:nsteps){
                    ret[, t] <- del + par.param[steps[t]]
                }
            }
        }else{
            tmp_a <- tmp_a[steps]
            tmp_b <- tmp_b[steps]
            for(i in 1:nsteps){
                ret[, i] <- stats::rbeta(nsims, tmp_a[i], tmp_b[i])
            }
        }
    }
    
    return(ret)
}

simulate_pars <- function(par.prior, par.param, nsims, nsteps, shift_only){
    
    start_prior <- par.prior[["start"]]
    
    if(start_prior > 1){   ### priors don't start at the first time point 
        
        ret <- matrix(NA, nsims, nsteps)
        if(length(par.param) == 1){
            ret[, c(1:(start_prior - 1))] <- par.param
        }else{
            ret[, c(1:(start_prior - 1))] <- rep(par.param[1:(start_prior - 1)], each = nsims)
        }
         
        steps <- c(start_prior:nsteps)
        if(par.prior$dist == "gaussian") ret[, c(start_prior:nsteps)] <- simulate_pars_gaussian(par.prior[["par"]], par.param, c(start_prior:nsteps), nsims, shift_only)
        if(par.prior$dist == "beta") ret[, c(start_prior:nsteps)] <- simulate_pars_beta(par.prior[["par"]], par.param, c(start_prior:nsteps), nsims, shift_only)
        
    }else{
        if(par.prior$dist == "gaussian") ret <- simulate_pars_gaussian(par.prior[["par"]], par.param, 1:nsteps, nsims, shift_only)
        if(par.prior$dist == "beta") ret <- simulate_pars_beta(par.prior[["par"]], par.param, 1:nsteps, nsims, shift_only)
    }
    
    return(ret)
}