#' @title Initial Conditions for Stochastic Individual Contact Models
#'
#' @description This function handles the initial conditions for stochastic individual contact
#'              models simulated with \code{\link{seiqhrf}}.
#'              
#' @param s.num Initial number of S compartment individuals in
#'     the simulated population. An overall population of 10,000 is a good
#'     compromise.
#' @param e.num Initial number of E compartment individuals in
#'     the simulated population.
#' @param i.num Initial number of I compartment individuals in
#'     the simulated population.
#' @param q.num Initial number of Q compartment individuals in
#'     the simulated population.
#' @param h.num Initial number of H compartment individuals in
#'      the simulated population.
#' @param r.num Initial number of R compartment individuals in
#'     the simulated population.
#' @param f.num Initial number of F compartment individuals in
#'     the simulated population.
#'
#' 
#' @seealso Use \code{\link{param_seiqhrf}} to specify model parameters and
#'          \code{\link{control_seiqhrf}} to specify the control settings. Run the
#'          parameterized model with \code{\link{seiqhrf}}.
#'
#' @keywords initialization
#'
#' @export
#'

init_seiqhrf <- function(s.num = 9997, e.num=0, i.num = 3, q.num=0, h.num=0, r.num = 0, f.num = 0) {

    p <- list()
    passed <- names(as.list(match.call())[-1])
    p$usr.specified <- passed
    
    formal.args <- formals(sys.function())
    for (arg in names(formal.args)) {
        if (as.logical(mget(arg) != "")) {
            p[arg] <- list(get(arg))
        }
    }
   
    
    ## Output
    class(p) <- c("init.seiqhrf", "list")
    return(p)
}